From fc6c466d8e0015b980f33408455481ef8f825d1a Mon Sep 17 00:00:00 2001
From: Rafael Fontenelle <rafaelff@gnome.org>
Date: Jan 22 2024 01:53:15 +0000
Subject: Fix misspellings


---

diff --git a/build.d/build.py b/build.d/build.py
index 82d5fd1..0e5afff 100755
--- a/build.d/build.py
+++ b/build.d/build.py
@@ -237,7 +237,7 @@ def process_dir(dirpath, filenames):
         if relpath == '': relpath = '.'
         safe_makedir(os.path.dirname(dest_file))
         template = loader.load(src_file)
-        # Variables made availble to all templates
+        # Variables made available to all templates
         page = template.generate(
             _=lambda text: translations.ugettext(text),
             feedparse=feedparse,
diff --git a/build.sh b/build.sh
index 75dd387..ce20cbc 100755
--- a/build.sh
+++ b/build.sh
@@ -15,7 +15,7 @@ if [ "$(uname)" == "Darwin" ]; then
 elif [ "$(expr substr $(uname -s) 1 5)" == "Linux" ]; then
     # Running on Linux.
     # there isn't an antora/aarch64 container, antora can be installed locally
-    # Check whether podman is available, else faill back to docker
+    # Check whether podman is available, else fall back to docker
     # which requires root.
 
     if [ -f /usr/local/bin/antora ]; then
diff --git a/docs/README.md b/docs/README.md
index 49fb545..af5aef7 100644
--- a/docs/README.md
+++ b/docs/README.md
@@ -38,7 +38,7 @@ This repository documentation for maintaining and adding new Fedora websites.
 
 Antora introduces two new terms:
 
-* **Component** — Simply put, a component is a part of the documentation website with its own menu. Components can also be versioned. In the Fedora Docs, we use separate components for user documentation, the Fedora Poject, Fedora council, Mindshare, FESCO, but also subprojects such as CommOps or Modulartity.
+* **Component** — Simply put, a component is a part of the documentation website with its own menu. Components can also be versioned. In the Fedora Docs, we use separate components for user documentation, the Fedora Project, Fedora council, Mindshare, FESCO, but also subprojects such as CommOps or Modulartity.
 * **Module** — A component can be broken down into multiple modules. Modules still share a single menu on the site, but their sources can be stored in different git repositories, even owned by different groups. The default module is called "ROOT" (that's what is in this example). If you don't want to use multiple modules, only use "ROOT". But to define more modules, simply duplicate the "ROOT" directory and name it anything you want. You can store modules in one or more git repositories.
 
 ## Local preview
diff --git a/docs/antora.yml b/docs/antora.yml
index 69a2892..8bd32eb 100644
--- a/docs/antora.yml
+++ b/docs/antora.yml
@@ -1,4 +1,4 @@
-# Name will be mostly visible in the URL. Treat it as an indentifier.
+# Name will be mostly visible in the URL. Treat it as an identifier.
 # Tip: If you want to use the local preview scripts that come with this repository, please change this value in the site.yml file as well. (under site/start_page)
 name: websites
 
diff --git a/docs/modules/ROOT/pages/contact.adoc b/docs/modules/ROOT/pages/contact.adoc
index 7a377db..6e9931e 100644
--- a/docs/modules/ROOT/pages/contact.adoc
+++ b/docs/modules/ROOT/pages/contact.adoc
@@ -21,5 +21,5 @@ In order to become a member of the Fedora Website & Apps Team, the applicant mus
 
 By becoming a Fedora Contributor, you accept these terms.
 
-* link:++https://fedoraproject.org/wiki/Legal:Fedora_Project_Contributor_Agreement++[Fedora Project Contributor Agrement (FPCA)]
+* link:++https://fedoraproject.org/wiki/Legal:Fedora_Project_Contributor_Agreement++[Fedora Project Contributor Agreement (FPCA)]
 * link:++https://docs.fedoraproject.org/en-US/project/code-of-conduct/++[Code of Conduct]
diff --git a/docs/modules/engg/pages/contact.adoc b/docs/modules/engg/pages/contact.adoc
index 4f728d9..afb0ac2 100644
--- a/docs/modules/engg/pages/contact.adoc
+++ b/docs/modules/engg/pages/contact.adoc
@@ -21,5 +21,5 @@ In order to become a member of the Fedora Website & Apps Team, the applicant mus
 
 By becoming a Fedora Contributor, you accept these terms.
 
-* link:++https://fedoraproject.org/wiki/Legal:Fedora_Project_Contributor_Agreement++[Fedora Project Contributor Agrement (FPCA)]
+* link:++https://fedoraproject.org/wiki/Legal:Fedora_Project_Contributor_Agreement++[Fedora Project Contributor Agreement (FPCA)]
 * link:++https://docs.fedoraproject.org/en-US/project/code-of-conduct/++[Code of Conduct]
diff --git a/docs/modules/engg/pages/old-websites-release.adoc b/docs/modules/engg/pages/old-websites-release.adoc
index 32a0767..60068f9 100644
--- a/docs/modules/engg/pages/old-websites-release.adoc
+++ b/docs/modules/engg/pages/old-websites-release.adoc
@@ -55,7 +55,7 @@ The output of fedora.gpg should contain only the actual keys, not the
 obsolete keys. The single text files should contain the correct
 information for the uploaded key.
 ** Next, add new key(s) to the list in `+data/verify.html+` and move the
-new key informations in the keys page in
+new key information in the keys page in
 `+data/content/keys/index.html+`. A script to aid in generating the HTML
 code for new keys is in `+./tools/make-gpg-key-html+`. It will print
 HTML to stdout for each RPM-GPG-KEY-* file given as arguments. This is
@@ -99,7 +99,7 @@ architectures.
 in all sidebars, also in labs, spins, and arm.fp.o.
 * Check all Download links and paths in
 `+${PRODUCT}/prerelease/index.html+` You can find all paths in bapp01
-(sudo su - mirrormanager first) or you can look at the downlaod page
+(sudo su - mirrormanager first) or you can look at the download page
 `+http://dl.fedoraproject.org/pub/alt/stage+`
 * Add CHECKSUM files to `+static/checksums+` and verify that the paths
 are correct. The files should be in sundries01 and you can query them
@@ -167,7 +167,7 @@ Make sure the banner is shown in all sidebars, also in labs, spins, and
 arm.fp.o.
 * Check all Download links and paths in
 `+${PRODUCT}/prerelease/index.html+` You can find all paths in bapp01
-(sudo su - mirrormanager first) or you can look at the downlaod page
+(sudo su - mirrormanager first) or you can look at the download page
 `+http://dl.fedoraproject.org/pub/alt/stage+`
 * Add CHECKSUM files to `+static/checksums+` and verify that the paths
 are correct. The files should be in sundries01 and you can query them
@@ -229,7 +229,7 @@ fedora-web git:(master) git checkout -t -b f23 origin/f23
 architectures.
 * Check all Download links and paths in
 `+${PRODUCT}/download/index.html+` You can find all paths in bapp01
-(sudo su - mirrormanager first) or you can look at the downlaod page
+(sudo su - mirrormanager first) or you can look at the download page
 `+http://dl.fedoraproject.org/pub/alt/stage+`
 * Add CHECKSUM files to `+static/checksums+` and verify that the paths
 are correct. The files should be in sundries01 and you can query them
diff --git a/docs/modules/rvmp/pages/contact.adoc b/docs/modules/rvmp/pages/contact.adoc
index 9e746be..702a055 100644
--- a/docs/modules/rvmp/pages/contact.adoc
+++ b/docs/modules/rvmp/pages/contact.adoc
@@ -21,5 +21,5 @@ In order to become a member of the Fedora Websites Revamp Stakeholders Team, the
 
 By becoming a Fedora Contributor, you accept these terms.
 
-* link:++https://fedoraproject.org/wiki/Legal:Fedora_Project_Contributor_Agreement++[Fedora Project Contributor Agrement (FPCA)]
+* link:++https://fedoraproject.org/wiki/Legal:Fedora_Project_Contributor_Agreement++[Fedora Project Contributor Agreement (FPCA)]
 * link:++https://docs.fedoraproject.org/en-US/project/code-of-conduct/++[Code of Conduct]
diff --git a/fedoracommunity.org/data/content/apac.html b/fedoracommunity.org/data/content/apac.html
index 9473daf..6448cdb 100644
--- a/fedoracommunity.org/data/content/apac.html
+++ b/fedoracommunity.org/data/content/apac.html
@@ -2,7 +2,7 @@
 import math
 from operator import itemgetter
 # see http://en.wikipedia.org/wiki/List_of_countries_and_capitals_in_native_languages
-contries = [
+countries = [
             {'name':'Indonesia',	'title':_('Fedora Indonesia Community'),      'url':'http://id.fedoracommunity.org'},
             {'name':'日本',		'title':_('Fedora Japan Community'),          'url':'http://fedorasrv.com'},
             {'name':'Philippines',	'title':_('Fedora Philippines Community'),    'url':'http://ph.fedoracommunity.org'},
@@ -12,8 +12,8 @@ contries = [
             {'name':'Taiwan',		'title':_('Fedora Taiwan Community'),         'url':'http://tw.fedoracommunity.org'}
 ]
 region="apac"
-contries.sort(key=itemgetter('name'))
-index=math.ceil(len(contries)/float(2))
+countries.sort(key=itemgetter('name'))
+index=math.ceil(len(countries)/float(2))
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml"
diff --git a/fedoracommunity.org/data/content/emea.html b/fedoracommunity.org/data/content/emea.html
index 131b992..99a90e1 100644
--- a/fedoracommunity.org/data/content/emea.html
+++ b/fedoracommunity.org/data/content/emea.html
@@ -2,7 +2,7 @@
 import math
 from operator import itemgetter
 # see http://en.wikipedia.org/wiki/List_of_countries_and_capitals_in_native_languages
-contries = [
+countries = [
             {'name':'Česká republika', 'title':_('Fedora Czech Republic Community'),           'url':'http://www.mojefedora.cz'},
             {'name':'France',          'title':_('Fedora French Community'),                   'url':'http://www.fedora-fr.org'},
             {'name':'Deutschland',     'title':_('Fedora unofficial German Fedora Portal'),    'url':'http://www.fedorausers.de'},
@@ -15,8 +15,8 @@ contries = [
             {'name':'Tunisie',         'title':_('Fedora Tunisia Community'),                  'url':'http://www.fedora-tunisia.org'}
 ]
 region="emea"
-contries.sort(key=itemgetter('name'))
-index=math.ceil(len(contries)/float(2))
+countries.sort(key=itemgetter('name'))
+index=math.ceil(len(countries)/float(2))
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml"
diff --git a/fedoracommunity.org/data/content/latam.html b/fedoracommunity.org/data/content/latam.html
index d96200b..09e46cb 100644
--- a/fedoracommunity.org/data/content/latam.html
+++ b/fedoracommunity.org/data/content/latam.html
@@ -1,14 +1,14 @@
 <?python
 import math
 from operator import itemgetter
-contries = [
+countries = [
             {'name':'Brasil',        'title':_('Fedora Brazil Portal'),            'url':'http://www.projetofedora.org'},
             {'name':'Chile',         'title':_('Fedora Chile Community'),          'url':'http://www.proyectofedora.cl'},
             {'name':'Nicaragua',     'title':_('Fedora Nicaragua Community'),      'url':'http://fedora.org.ni'},
 ]
 region="latam"
-contries.sort(key=itemgetter('name'))
-index=math.ceil(len(contries)/float(2))
+countries.sort(key=itemgetter('name'))
+index=math.ceil(len(countries)/float(2))
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml"
diff --git a/fedoracommunity.org/data/content/northam.html b/fedoracommunity.org/data/content/northam.html
index 59ca463..c65a354 100644
--- a/fedoracommunity.org/data/content/northam.html
+++ b/fedoracommunity.org/data/content/northam.html
@@ -1,13 +1,13 @@
 <?python
 import math
 from operator import itemgetter
-contries = [
+countries = [
             {'name':'United States', 'title':'Fedora', 'url':'http://fedoraproject.org'}
 
 ]
 region="northam"
-contries.sort(key=itemgetter('name'))
-index=math.ceil(len(contries)/float(2))
+countries.sort(key=itemgetter('name'))
+index=math.ceil(len(countries)/float(2))
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml"
diff --git a/fedoracommunity.org/data/templates/regions-site.html b/fedoracommunity.org/data/templates/regions-site.html
index 19457da..bcd61c3 100644
--- a/fedoracommunity.org/data/templates/regions-site.html
+++ b/fedoracommunity.org/data/templates/regions-site.html
@@ -18,14 +18,14 @@
 
           <!-- Left Column -->
           <div class="prefix_2 grid_7 ${region}">
-            <py:for each="country in contries[:int(index)]">
+            <py:for each="country in countries[:int(index)]">
                ${printblock()}
             </py:for>
           </div>
 
           <!-- Right Column -->
           <div class="grid_7 ${region}">
-            <py:for each="country in contries[int(index):]">
+            <py:for each="country in countries[int(index):]">
                ${printblock()}
             </py:for>
           </div>
diff --git a/httpd/conf/httpd.conf.in b/httpd/conf/httpd.conf.in
index e5d4208..da6f75a 100644
--- a/httpd/conf/httpd.conf.in
+++ b/httpd/conf/httpd.conf.in
@@ -473,7 +473,7 @@ MaxRequestsPerChild  0
 # English (en) - Esperanto (eo) - Estonian (et) - French (fr) - German (de)
 # Greek-Modern (el) - Hebrew (he) - Italian (it) - Japanese (ja)
 # Korean (ko) - Luxembourgeois* (ltz) - Norwegian Nynorsk (nn)
-# Norwegian (no) - Polish (pl) - Portugese (pt)
+# Norwegian (no) - Polish (pl) - Portuguese (pt)
 # Brazilian Portuguese (pt-BR) - Russian (ru) - Swedish (sv)
 # Simplified Chinese (zh-CN) - Spanish (es) - Traditional Chinese (zh-TW)
 #
diff --git a/httpd/conf/httpd.conf.old.in b/httpd/conf/httpd.conf.old.in
index 29c0b5d..a522a7f 100644
--- a/httpd/conf/httpd.conf.old.in
+++ b/httpd/conf/httpd.conf.old.in
@@ -689,7 +689,7 @@ IndexIgnore .??* *~ *# HEADER* README* RCS CVS *,v *,t
 # English (en) - Esperanto (eo) - Estonian (et) - French (fr) - German (de)
 # Greek-Modern (el) - Hebrew (he) - Italian (it) - Japanese (ja)
 # Korean (ko) - Luxembourgeois* (ltz) - Norwegian Nynorsk (nn)
-# Norwegian (no) - Polish (pl) - Portugese (pt)
+# Norwegian (no) - Polish (pl) - Portuguese (pt)
 # Brazilian Portuguese (pt-BR) - Russian (ru) - Swedish (sv)
 # Simplified Chinese (zh-CN) - Spanish (es) - Traditional Chinese (zh-TW)
 #
diff --git a/labs.fedoraproject.org/static/css/app.css b/labs.fedoraproject.org/static/css/app.css
index 0656d3a..1e94189 100644
--- a/labs.fedoraproject.org/static/css/app.css
+++ b/labs.fedoraproject.org/static/css/app.css
@@ -457,7 +457,7 @@ margin-top:4px;
 #head .screenshot-text h3 { color: #60605b; margin-top: 0px; }
 #head .screenshot-text a:hover { text-decoration: none; }
 #head .copr-astronomy { background:url(../images/astronomy/astronomy-splash.jpg) 50% 50% / cover no-repeat; position:relative; min-height: 230px; }
-#head .copr-comp-neuro { background:url(../images/comp-neuro/comp-neuro-splash.jpg) 50% 50% / cover no-repeat; postition:relative; min-height: 230px; }
+#head .copr-comp-neuro { background:url(../images/comp-neuro/comp-neuro-splash.jpg) 50% 50% / cover no-repeat; position:relative; min-height: 230px; }
 #head .copr-design { background:url(../images/design/design-splash.jpg) 50% 50% / cover no-repeat; position:relative; min-height: 230px; }
 #head .copr-games { background:url(../images/games/games-splash.jpg) 50% 50% / cover no-repeat; position:relative; min-height: 230px; }
 #head .copr-jam { background:url(../images/jam/jam-splash.jpg) 50% 50% / cover no-repeat; position:relative; min-height: 230px; }
diff --git a/tools/l10N_update.sh b/tools/l10N_update.sh
index d2cb119..ff8ba5b 100755
--- a/tools/l10N_update.sh
+++ b/tools/l10N_update.sh
@@ -1,5 +1,5 @@
 #!/bin/bash
 # this script pull all translations to tranlation repository,
 #      make an new POT and push it if asked,
 #      and then fill the LINGUAS file
 
@@ -36,20 +36,20 @@ This script update all L10n things. Will never git push.
 
 OPTIONS:
    -h      Show this message
-   -p      update POT on tranlation repository
+   -p      update POT on translation repository
 
 WEBSITE:
     The website targeted (like "fedoraproject.org")
-    Without WEBSITE specifyed, will parse the whole website array.
+    Without WEBSITE specified, will parse the whole website array.
 
 EXAMPLES:
          $ $0                                  (1)
          $ $0 -w ../spins.fedoraproject.org    (2)
          $ $0 -p                               (3)
 
-   1. Update all but let you git add and push to tranlation repository.
-   2. Pull POs + LINGUAS, generate pot of spins.fedoraproject.org website. Let you test localy.
-   3. Pull POs + LINGUAS, generate pot and push it to tranlation repository. That's what you were looking for.
+   1. Update all but let you git add and push to translation repository.
+   2. Pull POs + LINGUAS, generate pot of spins.fedoraproject.org website. Let you test locally.
+   3. Pull POs + LINGUAS, generate pot and push it to translation repository. That's what you were looking for.
 
 EOF
 }
@@ -1,5 +1,5 @@
 #!/bin/bash
-# this script pull all translations to tranlation repository,
+# this script pull all translations to translation repository,
 #      make an new POT and push it if asked,
 #      and then fill the LINGUAS file

